@@ -6,9 +6,7 @@ use {
         blockstore::Blockstore,
         blockstore_processor::{TransactionStatusBatch, TransactionStatusMessage},
     },
-    solana_runtime::bank::{
-        DurableNonceFee, TransactionExecutionDetails, TransactionExecutionResult,
-    },
+    solana_runtime::bank::{DurableNonceFee, TransactionExecutionDetails},
     solana_transaction_status::{
         extract_and_fmt_memos, InnerInstructions, Reward, TransactionStatusMeta,
     },
@@ -95,12 +93,13 @@ impl TransactionStatusService {
                     token_balances.post_token_balances,
                     rent_debits,
                 ) {
-                    if let TransactionExecutionResult::Executed(details) = execution_result {
+                    if let Some(details) = execution_result {
                         let TransactionExecutionDetails {
                             status,
                             log_messages,
                             inner_instructions,
                             durable_nonce_fee,
+                            ..
                         } = details;
                         let lamports_per_signature = match durable_nonce_fee {
                             Some(DurableNonceFee::Valid(lamports_per_signature)) => {
@@ -333,21 +332,21 @@ pub(crate) mod tests {
         let mut rent_debits = RentDebits::default();
         rent_debits.insert(&pubkey, 123, 456);
 
-        let transaction_result =
-            TransactionExecutionResult::Executed(TransactionExecutionDetails {
-                status: Ok(()),
-                log_messages: None,
-                inner_instructions: None,
-                durable_nonce_fee: Some(DurableNonceFee::from(
-                    &NonceFull::from_partial(
-                        rollback_partial,
-                        &SanitizedMessage::Legacy(message),
-                        &[(pubkey, nonce_account)],
-                        &rent_debits,
-                    )
-                    .unwrap(),
-                )),
-            });
+        let transaction_result = Some(TransactionExecutionDetails {
+            status: Ok(()),
+            log_messages: None,
+            inner_instructions: None,
+            durable_nonce_fee: Some(DurableNonceFee::from(
+                &NonceFull::from_partial(
+                    rollback_partial,
+                    &SanitizedMessage::Legacy(message),
+                    &[(pubkey, nonce_account)],
+                    &rent_debits,
+                )
+                .unwrap(),
+            )),
+            executed_units: 0u64,
+        });
 
         let balances = TransactionBalancesSet {
             pre_balances: vec![vec![123456]],
